@@ -21,7 +21,7 @@ pub enum CCashUsernameError {
 }
 
 /// User struct that can be used for authentication purposes.
-#[derive(Debug, Clone, serde::Serialize, Hash, PartialEq, Eq)]
+#[derive(Debug, Clone, serde::Serialize, serde::Deserialize, Hash, PartialEq, Eq)]
 pub struct CCashUser {
     #[serde(rename(serialize = "name"))]
     pub(crate) username: String,
